# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: state.proto
import sys

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from . import type_pb2 as type__pb2
_b = sys.version_info[0] < 3 and (
    lambda x: x
) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='state.proto',
    package='forge_abi',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\x0bstate.proto\x12\tforge_abi\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\ntype.proto\"\x9c\x03\n\x0c\x41\x63\x63ountState\x12#\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x12.forge_abi.BigUint\x12\r\n\x05nonce\x18\x02 \x01(\x04\x12\x0f\n\x07num_txs\x18\x03 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12\n\n\x02pk\x18\x05 \x01(\x0c\x12#\n\x04type\x18\x06 \x01(\x0b\x32\x15.forge_abi.WalletType\x12\x0f\n\x07moniker\x18\x07 \x01(\t\x12(\n\x07\x63ontext\x18\x08 \x01(\x0b\x32\x17.forge_abi.StateContext\x12\x0e\n\x06issuer\x18\t \x01(\t\x12\x13\n\x0bmigrated_to\x18\r \x03(\t\x12\x15\n\rmigrated_from\x18\x0e \x03(\t\x12\x12\n\nnum_assets\x18\x0f \x01(\x04\x12&\n\x05stake\x18\x10 \x01(\x0b\x32\x17.forge_abi.StakeContext\x12.\n\x0cpinned_files\x18\x11 \x01(\x0b\x32\x18.forge_abi.CircularQueue\x12\"\n\x04\x64\x61ta\x18\x32 \x01(\x0b\x32\x14.google.protobuf.Any\"\xac\x02\n\nAssetState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x10\n\x08readonly\x18\x04 \x01(\x08\x12\x15\n\rtransferrable\x18\x05 \x01(\x08\x12\x0b\n\x03ttl\x18\x06 \x01(\r\x12\x31\n\rconsumed_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06issuer\x18\x08 \x01(\t\x12&\n\x05stake\x18\r \x01(\x0b\x32\x17.forge_abi.StakeContext\x12(\n\x07\x63ontext\x18\x0e \x01(\x0b\x32\x17.forge_abi.StateContext\x12\"\n\x04\x64\x61ta\x18\x32 \x01(\x0b\x32\x14.google.protobuf.Any\"\xb5\x03\n\nForgeState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12-\n\tconsensus\x18\x02 \x01(\x0b\x32\x1a.forge_abi.ConsensusParams\x12/\n\x05tasks\x18\x03 \x03(\x0b\x32 .forge_abi.ForgeState.TasksEntry\x12>\n\rstake_summary\x18\x04 \x03(\x0b\x32\'.forge_abi.ForgeState.StakeSummaryEntry\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x14\n\x0c\x64\x61ta_version\x18\x06 \x01(\t\x12\x16\n\x0e\x66orge_app_hash\x18\x07 \x01(\x0c\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\x1a\x45\n\nTasksEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.forge_abi.UpgradeTasks:\x02\x38\x01\x1aL\n\x11StakeSummaryEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.forge_abi.StakeSummary:\x02\x38\x01\"M\n\tRootState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0c\x12\r\n\x05\x61sset\x18\x03 \x01(\x0c\x12\x0f\n\x07receipt\x18\x04 \x01(\x0c\"\xbb\x01\n\nStakeState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\n\n\x02to\x18\x03 \x01(\t\x12#\n\x07\x62\x61lance\x18\x04 \x01(\x0b\x32\x12.forge_abi.BigUint\x12\x0f\n\x07message\x18\x05 \x01(\t\x12(\n\x07\x63ontext\x18\x0e \x01(\x0b\x32\x17.forge_abi.StateContext\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"\xb7\x01\n\x0fStatisticsState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\nnum_blocks\x18\x02 \x01(\x04\x12\x0f\n\x07num_txs\x18\x03 \x01(\x04\x12&\n\nnum_stakes\x18\x04 \x01(\x0b\x32\x12.forge_abi.BigUint\x12\x16\n\x0enum_validators\x18\x05 \x01(\r\x12.\n\rtx_statistics\x18\x06 \x01(\x0b\x32\x17.forge_abi.TxStatisticsb\x06proto3'),
    dependencies=[
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR, type__pb2.DESCRIPTOR, ],
)


_ACCOUNTSTATE = _descriptor.Descriptor(
    name='AccountState',
    full_name='forge_abi.AccountState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='balance', full_name='forge_abi.AccountState.balance', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='nonce', full_name='forge_abi.AccountState.nonce', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_txs', full_name='forge_abi.AccountState.num_txs', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.AccountState.address', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='pk', full_name='forge_abi.AccountState.pk', index=4,
            number=5, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.AccountState.type', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.AccountState.moniker', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='context', full_name='forge_abi.AccountState.context', index=7,
            number=8, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='issuer', full_name='forge_abi.AccountState.issuer', index=8,
            number=9, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='migrated_to', full_name='forge_abi.AccountState.migrated_to', index=9,
            number=13, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='migrated_from', full_name='forge_abi.AccountState.migrated_from', index=10,
            number=14, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_assets', full_name='forge_abi.AccountState.num_assets', index=11,
            number=15, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stake', full_name='forge_abi.AccountState.stake', index=12,
            number=16, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='pinned_files', full_name='forge_abi.AccountState.pinned_files', index=13,
            number=17, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.AccountState.data', index=14,
            number=50, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=99,
    serialized_end=511,
)


_ASSETSTATE = _descriptor.Descriptor(
    name='AssetState',
    full_name='forge_abi.AssetState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.AssetState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='owner', full_name='forge_abi.AssetState.owner', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.AssetState.moniker', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='readonly', full_name='forge_abi.AssetState.readonly', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='transferrable', full_name='forge_abi.AssetState.transferrable', index=4,
            number=5, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='ttl', full_name='forge_abi.AssetState.ttl', index=5,
            number=6, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consumed_time', full_name='forge_abi.AssetState.consumed_time', index=6,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='issuer', full_name='forge_abi.AssetState.issuer', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stake', full_name='forge_abi.AssetState.stake', index=8,
            number=13, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='context', full_name='forge_abi.AssetState.context', index=9,
            number=14, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.AssetState.data', index=10,
            number=50, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=514,
    serialized_end=814,
)


_FORGESTATE_TASKSENTRY = _descriptor.Descriptor(
    name='TasksEntry',
    full_name='forge_abi.ForgeState.TasksEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='forge_abi.ForgeState.TasksEntry.key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.ForgeState.TasksEntry.value', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1107,
    serialized_end=1176,
)

_FORGESTATE_STAKESUMMARYENTRY = _descriptor.Descriptor(
    name='StakeSummaryEntry',
    full_name='forge_abi.ForgeState.StakeSummaryEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='forge_abi.ForgeState.StakeSummaryEntry.key', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.ForgeState.StakeSummaryEntry.value', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1178,
    serialized_end=1254,
)

_FORGESTATE = _descriptor.Descriptor(
    name='ForgeState',
    full_name='forge_abi.ForgeState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.ForgeState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consensus', full_name='forge_abi.ForgeState.consensus', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tasks', full_name='forge_abi.ForgeState.tasks', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stake_summary', full_name='forge_abi.ForgeState.stake_summary', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='version', full_name='forge_abi.ForgeState.version', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data_version', full_name='forge_abi.ForgeState.data_version', index=5,
            number=6, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='forge_app_hash', full_name='forge_abi.ForgeState.forge_app_hash', index=6,
            number=7, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.ForgeState.data', index=7,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[_FORGESTATE_TASKSENTRY, _FORGESTATE_STAKESUMMARYENTRY, ],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=817,
    serialized_end=1254,
)


_ROOTSTATE = _descriptor.Descriptor(
    name='RootState',
    full_name='forge_abi.RootState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.RootState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='account', full_name='forge_abi.RootState.account', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='asset', full_name='forge_abi.RootState.asset', index=2,
            number=3, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='receipt', full_name='forge_abi.RootState.receipt', index=3,
            number=4, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1256,
    serialized_end=1333,
)


_STAKESTATE = _descriptor.Descriptor(
    name='StakeState',
    full_name='forge_abi.StakeState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.StakeState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='from', full_name='forge_abi.StakeState.from', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='to', full_name='forge_abi.StakeState.to', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='balance', full_name='forge_abi.StakeState.balance', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='message', full_name='forge_abi.StakeState.message', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='context', full_name='forge_abi.StakeState.context', index=5,
            number=14, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.StakeState.data', index=6,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1336,
    serialized_end=1523,
)


_STATISTICSSTATE = _descriptor.Descriptor(
    name='StatisticsState',
    full_name='forge_abi.StatisticsState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.StatisticsState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_blocks', full_name='forge_abi.StatisticsState.num_blocks', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_txs', full_name='forge_abi.StatisticsState.num_txs', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_stakes', full_name='forge_abi.StatisticsState.num_stakes', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_validators', full_name='forge_abi.StatisticsState.num_validators', index=4,
            number=5, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tx_statistics', full_name='forge_abi.StatisticsState.tx_statistics', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1526,
    serialized_end=1709,
)

_ACCOUNTSTATE.fields_by_name['balance'].message_type = type__pb2._BIGUINT
_ACCOUNTSTATE.fields_by_name['type'].message_type = type__pb2._WALLETTYPE
_ACCOUNTSTATE.fields_by_name['context'].message_type = type__pb2._STATECONTEXT
_ACCOUNTSTATE.fields_by_name['stake'].message_type = type__pb2._STAKECONTEXT
_ACCOUNTSTATE.fields_by_name['pinned_files'].message_type = type__pb2._CIRCULARQUEUE
_ACCOUNTSTATE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ASSETSTATE.fields_by_name['consumed_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ASSETSTATE.fields_by_name['stake'].message_type = type__pb2._STAKECONTEXT
_ASSETSTATE.fields_by_name['context'].message_type = type__pb2._STATECONTEXT
_ASSETSTATE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FORGESTATE_TASKSENTRY.fields_by_name['value'].message_type = type__pb2._UPGRADETASKS
_FORGESTATE_TASKSENTRY.containing_type = _FORGESTATE
_FORGESTATE_STAKESUMMARYENTRY.fields_by_name['value'].message_type = type__pb2._STAKESUMMARY
_FORGESTATE_STAKESUMMARYENTRY.containing_type = _FORGESTATE
_FORGESTATE.fields_by_name['consensus'].message_type = type__pb2._CONSENSUSPARAMS
_FORGESTATE.fields_by_name['tasks'].message_type = _FORGESTATE_TASKSENTRY
_FORGESTATE.fields_by_name['stake_summary'].message_type = _FORGESTATE_STAKESUMMARYENTRY
_FORGESTATE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STAKESTATE.fields_by_name['balance'].message_type = type__pb2._BIGUINT
_STAKESTATE.fields_by_name['context'].message_type = type__pb2._STATECONTEXT
_STAKESTATE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATISTICSSTATE.fields_by_name['num_stakes'].message_type = type__pb2._BIGUINT
_STATISTICSSTATE.fields_by_name['tx_statistics'].message_type = type__pb2._TXSTATISTICS
DESCRIPTOR.message_types_by_name['AccountState'] = _ACCOUNTSTATE
DESCRIPTOR.message_types_by_name['AssetState'] = _ASSETSTATE
DESCRIPTOR.message_types_by_name['ForgeState'] = _FORGESTATE
DESCRIPTOR.message_types_by_name['RootState'] = _ROOTSTATE
DESCRIPTOR.message_types_by_name['StakeState'] = _STAKESTATE
DESCRIPTOR.message_types_by_name['StatisticsState'] = _STATISTICSSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountState = _reflection.GeneratedProtocolMessageType(
    'AccountState', (_message.Message,), dict(
        DESCRIPTOR=_ACCOUNTSTATE,
        __module__='state_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.AccountState)
    ),
)
_sym_db.RegisterMessage(AccountState)

AssetState = _reflection.GeneratedProtocolMessageType(
    'AssetState', (_message.Message,), dict(
        DESCRIPTOR=_ASSETSTATE,
        __module__='state_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.AssetState)
    ),
)
_sym_db.RegisterMessage(AssetState)

ForgeState = _reflection.GeneratedProtocolMessageType(
    'ForgeState', (_message.Message,), dict(

        TasksEntry=_reflection.GeneratedProtocolMessageType(
            'TasksEntry', (_message.Message,), dict(
                DESCRIPTOR=_FORGESTATE_TASKSENTRY,
                __module__='state_pb2',
                # @@protoc_insertion_point(class_scope:forge_abi.ForgeState.TasksEntry)
            ),
        ),

        StakeSummaryEntry=_reflection.GeneratedProtocolMessageType(
            'StakeSummaryEntry', (_message.Message,), dict(
                DESCRIPTOR=_FORGESTATE_STAKESUMMARYENTRY,
                __module__='state_pb2',
                # @@protoc_insertion_point(class_scope:forge_abi.ForgeState.StakeSummaryEntry)
            ),
        ),
        DESCRIPTOR=_FORGESTATE,
        __module__='state_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ForgeState)
    ),
)
_sym_db.RegisterMessage(ForgeState)
_sym_db.RegisterMessage(ForgeState.TasksEntry)
_sym_db.RegisterMessage(ForgeState.StakeSummaryEntry)

RootState = _reflection.GeneratedProtocolMessageType(
    'RootState', (_message.Message,), dict(
        DESCRIPTOR=_ROOTSTATE,
        __module__='state_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RootState)
    ),
)
_sym_db.RegisterMessage(RootState)

StakeState = _reflection.GeneratedProtocolMessageType(
    'StakeState', (_message.Message,), dict(
        DESCRIPTOR=_STAKESTATE,
        __module__='state_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StakeState)
    ),
)
_sym_db.RegisterMessage(StakeState)

StatisticsState = _reflection.GeneratedProtocolMessageType(
    'StatisticsState', (_message.Message,), dict(
        DESCRIPTOR=_STATISTICSSTATE,
        __module__='state_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StatisticsState)
    ),
)
_sym_db.RegisterMessage(StatisticsState)


_FORGESTATE_TASKSENTRY._options = None
_FORGESTATE_STAKESUMMARYENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tx.proto
import sys

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from . import type_pb2 as type__pb2
_b = sys.version_info[0] < 3 and (
    lambda x: x
) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='tx.proto',
    package='forge_abi',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\x08tx.proto\x12\tforge_abi\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\ntype.proto\"C\n\x10\x41\x63\x63ountMigrateTx\x12\n\n\x02pk\x18\x01 \x01(\x0c\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x15.forge_abi.WalletType\"\xb6\x01\n\x12\x43onsensusUpgradeTx\x12(\n\nvalidators\x18\x01 \x03(\x0b\x32\x14.forge_abi.Validator\x12\x11\n\tmax_bytes\x18\x02 \x01(\x04\x12\x0f\n\x07max_gas\x18\x03 \x01(\x12\x12\x16\n\x0emax_validators\x18\x04 \x01(\r\x12\x16\n\x0emax_candidates\x18\x05 \x01(\r\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"U\n\x0e\x43onsumeAssetTx\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"\x8a\x01\n\rCreateAssetTx\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x10\n\x08readonly\x18\x03 \x01(\x08\x12\x15\n\rtransferrable\x18\x04 \x01(\x08\x12\x0b\n\x03ttl\x18\x05 \x01(\r\x12\x0e\n\x06parent\x18\x06 \x01(\t\"\x81\x01\n\tDeclareTx\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\n\n\x02pk\x18\x02 \x01(\x0c\x12#\n\x04type\x18\x03 \x01(\x0b\x32\x15.forge_abi.WalletType\x12\x0e\n\x06issuer\x18\x04 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"\x1d\n\rDeclareFileTx\x12\x0c\n\x04hash\x18\x01 \x01(\t\"A\n\x0c\x45xchangeInfo\x12!\n\x05value\x18\x01 \x01(\x0b\x32\x12.forge_abi.BigUint\x12\x0e\n\x06\x61ssets\x18\x02 \x03(\t\"\xc0\x01\n\nExchangeTx\x12\n\n\x02to\x18\x01 \x01(\t\x12\'\n\x06sender\x18\x02 \x01(\x0b\x32\x17.forge_abi.ExchangeInfo\x12)\n\x08receiver\x18\x03 \x01(\x0b\x32\x17.forge_abi.ExchangeInfo\x12.\n\nexpired_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"\x0f\n\rstakeForAsset\"\x0f\n\rstakeForChain\"\x0e\n\x0cStakeForNode\"\x0e\n\x0cstakeForUser\"m\n\x07StakeTx\x12\n\n\x02to\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.forge_abi.BigSint\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"n\n\x0cSysUpgradeTx\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.forge_abi.UpgradeTask\x12\x14\n\x0cgrace_period\x18\x02 \x01(\x04\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"o\n\nTransferTx\x12\n\n\x02to\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.forge_abi.BigUint\x12\x0e\n\x06\x61ssets\x18\x03 \x03(\t\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Any\"U\n\rUpdateAssetTx\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07moniker\x18\x02 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x0f \x01(\x0b\x32\x14.google.protobuf.Anyb\x06proto3'),
    dependencies=[
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR, type__pb2.DESCRIPTOR, ],
)


_ACCOUNTMIGRATETX = _descriptor.Descriptor(
    name='AccountMigrateTx',
    full_name='forge_abi.AccountMigrateTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='pk', full_name='forge_abi.AccountMigrateTx.pk', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.AccountMigrateTx.type', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=95,
    serialized_end=162,
)


_CONSENSUSUPGRADETX = _descriptor.Descriptor(
    name='ConsensusUpgradeTx',
    full_name='forge_abi.ConsensusUpgradeTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='validators', full_name='forge_abi.ConsensusUpgradeTx.validators', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_bytes', full_name='forge_abi.ConsensusUpgradeTx.max_bytes', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_gas', full_name='forge_abi.ConsensusUpgradeTx.max_gas', index=2,
            number=3, type=18, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_validators', full_name='forge_abi.ConsensusUpgradeTx.max_validators', index=3,
            number=4, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_candidates', full_name='forge_abi.ConsensusUpgradeTx.max_candidates', index=4,
            number=5, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.ConsensusUpgradeTx.data', index=5,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=165,
    serialized_end=347,
)


_CONSUMEASSETTX = _descriptor.Descriptor(
    name='ConsumeAssetTx',
    full_name='forge_abi.ConsumeAssetTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='issuer', full_name='forge_abi.ConsumeAssetTx.issuer', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.ConsumeAssetTx.address', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.ConsumeAssetTx.data', index=2,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=349,
    serialized_end=434,
)


_CREATEASSETTX = _descriptor.Descriptor(
    name='CreateAssetTx',
    full_name='forge_abi.CreateAssetTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.CreateAssetTx.moniker', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.CreateAssetTx.data', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='readonly', full_name='forge_abi.CreateAssetTx.readonly', index=2,
            number=3, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='transferrable', full_name='forge_abi.CreateAssetTx.transferrable', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='ttl', full_name='forge_abi.CreateAssetTx.ttl', index=4,
            number=5, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='parent', full_name='forge_abi.CreateAssetTx.parent', index=5,
            number=6, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=437,
    serialized_end=575,
)


_DECLARETX = _descriptor.Descriptor(
    name='DeclareTx',
    full_name='forge_abi.DeclareTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.DeclareTx.moniker', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='pk', full_name='forge_abi.DeclareTx.pk', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.DeclareTx.type', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='issuer', full_name='forge_abi.DeclareTx.issuer', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.DeclareTx.data', index=4,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=578,
    serialized_end=707,
)


_DECLAREFILETX = _descriptor.Descriptor(
    name='DeclareFileTx',
    full_name='forge_abi.DeclareFileTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.DeclareFileTx.hash', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=709,
    serialized_end=738,
)


_EXCHANGEINFO = _descriptor.Descriptor(
    name='ExchangeInfo',
    full_name='forge_abi.ExchangeInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.ExchangeInfo.value', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='assets', full_name='forge_abi.ExchangeInfo.assets', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=740,
    serialized_end=805,
)


_EXCHANGETX = _descriptor.Descriptor(
    name='ExchangeTx',
    full_name='forge_abi.ExchangeTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='to', full_name='forge_abi.ExchangeTx.to', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='sender', full_name='forge_abi.ExchangeTx.sender', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='receiver', full_name='forge_abi.ExchangeTx.receiver', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='expired_at', full_name='forge_abi.ExchangeTx.expired_at', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.ExchangeTx.data', index=4,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=808,
    serialized_end=1000,
)


_STAKEFORASSET = _descriptor.Descriptor(
    name='stakeForAsset',
    full_name='forge_abi.stakeForAsset',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1002,
    serialized_end=1017,
)


_STAKEFORCHAIN = _descriptor.Descriptor(
    name='stakeForChain',
    full_name='forge_abi.stakeForChain',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1019,
    serialized_end=1034,
)


_STAKEFORNODE = _descriptor.Descriptor(
    name='StakeForNode',
    full_name='forge_abi.StakeForNode',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1036,
    serialized_end=1050,
)


_STAKEFORUSER = _descriptor.Descriptor(
    name='stakeForUser',
    full_name='forge_abi.stakeForUser',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1052,
    serialized_end=1066,
)


_STAKETX = _descriptor.Descriptor(
    name='StakeTx',
    full_name='forge_abi.StakeTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='to', full_name='forge_abi.StakeTx.to', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.StakeTx.value', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='message', full_name='forge_abi.StakeTx.message', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.StakeTx.data', index=3,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1068,
    serialized_end=1177,
)


_SYSUPGRADETX = _descriptor.Descriptor(
    name='SysUpgradeTx',
    full_name='forge_abi.SysUpgradeTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='task', full_name='forge_abi.SysUpgradeTx.task', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='grace_period', full_name='forge_abi.SysUpgradeTx.grace_period', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.SysUpgradeTx.data', index=2,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1179,
    serialized_end=1289,
)


_TRANSFERTX = _descriptor.Descriptor(
    name='TransferTx',
    full_name='forge_abi.TransferTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='to', full_name='forge_abi.TransferTx.to', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.TransferTx.value', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='assets', full_name='forge_abi.TransferTx.assets', index=2,
            number=3, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.TransferTx.data', index=3,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1291,
    serialized_end=1402,
)


_UPDATEASSETTX = _descriptor.Descriptor(
    name='UpdateAssetTx',
    full_name='forge_abi.UpdateAssetTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.UpdateAssetTx.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.UpdateAssetTx.moniker', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.UpdateAssetTx.data', index=2,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1404,
    serialized_end=1489,
)

_ACCOUNTMIGRATETX.fields_by_name['type'].message_type = type__pb2._WALLETTYPE
_CONSENSUSUPGRADETX.fields_by_name['validators'].message_type = type__pb2._VALIDATOR
_CONSENSUSUPGRADETX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CONSUMEASSETTX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CREATEASSETTX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DECLARETX.fields_by_name['type'].message_type = type__pb2._WALLETTYPE
_DECLARETX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXCHANGEINFO.fields_by_name['value'].message_type = type__pb2._BIGUINT
_EXCHANGETX.fields_by_name['sender'].message_type = _EXCHANGEINFO
_EXCHANGETX.fields_by_name['receiver'].message_type = _EXCHANGEINFO
_EXCHANGETX.fields_by_name['expired_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXCHANGETX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STAKETX.fields_by_name['value'].message_type = type__pb2._BIGSINT
_STAKETX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SYSUPGRADETX.fields_by_name['task'].message_type = type__pb2._UPGRADETASK
_SYSUPGRADETX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRANSFERTX.fields_by_name['value'].message_type = type__pb2._BIGUINT
_TRANSFERTX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UPDATEASSETTX.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['AccountMigrateTx'] = _ACCOUNTMIGRATETX
DESCRIPTOR.message_types_by_name['ConsensusUpgradeTx'] = _CONSENSUSUPGRADETX
DESCRIPTOR.message_types_by_name['ConsumeAssetTx'] = _CONSUMEASSETTX
DESCRIPTOR.message_types_by_name['CreateAssetTx'] = _CREATEASSETTX
DESCRIPTOR.message_types_by_name['DeclareTx'] = _DECLARETX
DESCRIPTOR.message_types_by_name['DeclareFileTx'] = _DECLAREFILETX
DESCRIPTOR.message_types_by_name['ExchangeInfo'] = _EXCHANGEINFO
DESCRIPTOR.message_types_by_name['ExchangeTx'] = _EXCHANGETX
DESCRIPTOR.message_types_by_name['stakeForAsset'] = _STAKEFORASSET
DESCRIPTOR.message_types_by_name['stakeForChain'] = _STAKEFORCHAIN
DESCRIPTOR.message_types_by_name['StakeForNode'] = _STAKEFORNODE
DESCRIPTOR.message_types_by_name['stakeForUser'] = _STAKEFORUSER
DESCRIPTOR.message_types_by_name['StakeTx'] = _STAKETX
DESCRIPTOR.message_types_by_name['SysUpgradeTx'] = _SYSUPGRADETX
DESCRIPTOR.message_types_by_name['TransferTx'] = _TRANSFERTX
DESCRIPTOR.message_types_by_name['UpdateAssetTx'] = _UPDATEASSETTX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountMigrateTx = _reflection.GeneratedProtocolMessageType(
    'AccountMigrateTx', (_message.Message,), dict(
        DESCRIPTOR=_ACCOUNTMIGRATETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.AccountMigrateTx)
    ),
)
_sym_db.RegisterMessage(AccountMigrateTx)

ConsensusUpgradeTx = _reflection.GeneratedProtocolMessageType(
    'ConsensusUpgradeTx', (_message.Message,), dict(
        DESCRIPTOR=_CONSENSUSUPGRADETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ConsensusUpgradeTx)
    ),
)
_sym_db.RegisterMessage(ConsensusUpgradeTx)

ConsumeAssetTx = _reflection.GeneratedProtocolMessageType(
    'ConsumeAssetTx', (_message.Message,), dict(
        DESCRIPTOR=_CONSUMEASSETTX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ConsumeAssetTx)
    ),
)
_sym_db.RegisterMessage(ConsumeAssetTx)

CreateAssetTx = _reflection.GeneratedProtocolMessageType(
    'CreateAssetTx', (_message.Message,), dict(
        DESCRIPTOR=_CREATEASSETTX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.CreateAssetTx)
    ),
)
_sym_db.RegisterMessage(CreateAssetTx)

DeclareTx = _reflection.GeneratedProtocolMessageType(
    'DeclareTx', (_message.Message,), dict(
        DESCRIPTOR=_DECLARETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.DeclareTx)
    ),
)
_sym_db.RegisterMessage(DeclareTx)

DeclareFileTx = _reflection.GeneratedProtocolMessageType(
    'DeclareFileTx', (_message.Message,), dict(
        DESCRIPTOR=_DECLAREFILETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.DeclareFileTx)
    ),
)
_sym_db.RegisterMessage(DeclareFileTx)

ExchangeInfo = _reflection.GeneratedProtocolMessageType(
    'ExchangeInfo', (_message.Message,), dict(
        DESCRIPTOR=_EXCHANGEINFO,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ExchangeInfo)
    ),
)
_sym_db.RegisterMessage(ExchangeInfo)

ExchangeTx = _reflection.GeneratedProtocolMessageType(
    'ExchangeTx', (_message.Message,), dict(
        DESCRIPTOR=_EXCHANGETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ExchangeTx)
    ),
)
_sym_db.RegisterMessage(ExchangeTx)

stakeForAsset = _reflection.GeneratedProtocolMessageType(
    'stakeForAsset', (_message.Message,), dict(
        DESCRIPTOR=_STAKEFORASSET,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.stakeForAsset)
    ),
)
_sym_db.RegisterMessage(stakeForAsset)

stakeForChain = _reflection.GeneratedProtocolMessageType(
    'stakeForChain', (_message.Message,), dict(
        DESCRIPTOR=_STAKEFORCHAIN,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.stakeForChain)
    ),
)
_sym_db.RegisterMessage(stakeForChain)

StakeForNode = _reflection.GeneratedProtocolMessageType(
    'StakeForNode', (_message.Message,), dict(
        DESCRIPTOR=_STAKEFORNODE,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StakeForNode)
    ),
)
_sym_db.RegisterMessage(StakeForNode)

stakeForUser = _reflection.GeneratedProtocolMessageType(
    'stakeForUser', (_message.Message,), dict(
        DESCRIPTOR=_STAKEFORUSER,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.stakeForUser)
    ),
)
_sym_db.RegisterMessage(stakeForUser)

StakeTx = _reflection.GeneratedProtocolMessageType(
    'StakeTx', (_message.Message,), dict(
        DESCRIPTOR=_STAKETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StakeTx)
    ),
)
_sym_db.RegisterMessage(StakeTx)

SysUpgradeTx = _reflection.GeneratedProtocolMessageType(
    'SysUpgradeTx', (_message.Message,), dict(
        DESCRIPTOR=_SYSUPGRADETX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.SysUpgradeTx)
    ),
)
_sym_db.RegisterMessage(SysUpgradeTx)

TransferTx = _reflection.GeneratedProtocolMessageType(
    'TransferTx', (_message.Message,), dict(
        DESCRIPTOR=_TRANSFERTX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.TransferTx)
    ),
)
_sym_db.RegisterMessage(TransferTx)

UpdateAssetTx = _reflection.GeneratedProtocolMessageType(
    'UpdateAssetTx', (_message.Message,), dict(
        DESCRIPTOR=_UPDATEASSETTX,
        __module__='tx_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.UpdateAssetTx)
    ),
)
_sym_db.RegisterMessage(UpdateAssetTx)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: abi.proto
import sys

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

from . import enum_pb2 as enum__pb2
from . import state_pb2 as state__pb2
from . import type_pb2 as type__pb2
_b = sys.version_info[0] < 3 and (
    lambda x: x
) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='abi.proto',
    package='forge_abi',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\tabi.proto\x12\tforge_abi\x1a\nenum.proto\x1a\ntype.proto\x1a\x0bstate.proto\"\xff\x01\n\x0fRequestVerifyTx\x12\"\n\x02tx\x18\x01 \x01(\x0b\x32\x16.forge_abi.Transaction\x12\'\n\x06states\x18\x02 \x03(\x0b\x32\x17.forge_abi.AccountState\x12%\n\x06\x61ssets\x18\x03 \x03(\x0b\x32\x15.forge_abi.AssetState\x12%\n\x06stakes\x18\x04 \x03(\x0b\x32\x15.forge_abi.StakeState\x12\'\n\x07\x63ontext\x18\x05 \x01(\x0b\x32\x16.forge_abi.AbciContext\x12(\n\tapp_state\x18\x0f \x01(\x0b\x32\x15.forge_abi.ForgeState\"7\n\x10ResponseVerifyTx\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\"\x82\x02\n\x12RequestUpdateState\x12\"\n\x02tx\x18\x01 \x01(\x0b\x32\x16.forge_abi.Transaction\x12\'\n\x06states\x18\x02 \x03(\x0b\x32\x17.forge_abi.AccountState\x12%\n\x06\x61ssets\x18\x03 \x03(\x0b\x32\x15.forge_abi.AssetState\x12%\n\x06stakes\x18\x04 \x03(\x0b\x32\x15.forge_abi.StakeState\x12\'\n\x07\x63ontext\x18\x05 \x01(\x0b\x32\x16.forge_abi.AbciContext\x12(\n\tapp_state\x18\x0f \x01(\x0b\x32\x15.forge_abi.ForgeState\"\xdb\x01\n\x13ResponseUpdateState\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\'\n\x06states\x18\x02 \x03(\x0b\x32\x17.forge_abi.AccountState\x12%\n\x06\x61ssets\x18\x03 \x03(\x0b\x32\x15.forge_abi.AssetState\x12%\n\x06stakes\x18\x04 \x03(\x0b\x32\x15.forge_abi.StakeState\x12(\n\tapp_state\x18\x0f \x01(\x0b\x32\x15.forge_abi.ForgeState\"$\n\x0bRequestInfo\x12\x15\n\rforge_version\x18\x01 \x01(\t\"3\n\x0cResponseInfo\x12\x11\n\ttype_urls\x18\x01 \x03(\t\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c\"\xa2\x01\n\x07Request\x12/\n\tverify_tx\x18\x01 \x01(\x0b\x32\x1a.forge_abi.RequestVerifyTxH\x00\x12\x35\n\x0cupdate_state\x18\x02 \x01(\x0b\x32\x1d.forge_abi.RequestUpdateStateH\x00\x12&\n\x04info\x18\x03 \x01(\x0b\x32\x16.forge_abi.RequestInfoH\x00\x42\x07\n\x05value\"\xa6\x01\n\x08Response\x12\x30\n\tverify_tx\x18\x01 \x01(\x0b\x32\x1b.forge_abi.ResponseVerifyTxH\x00\x12\x36\n\x0cupdate_state\x18\x02 \x01(\x0b\x32\x1e.forge_abi.ResponseUpdateStateH\x00\x12\'\n\x04info\x18\x03 \x01(\x0b\x32\x17.forge_abi.ResponseInfoH\x00\x42\x07\n\x05value2}\n\x0b\x46orgeAppRpc\x12\x36\n\x0bprocess_one\x12\x12.forge_abi.Request\x1a\x13.forge_abi.Response\x12\x36\n\x07process\x12\x12.forge_abi.Request\x1a\x13.forge_abi.Response(\x01\x30\x01\x62\x06proto3'),
    dependencies=[
        enum__pb2.DESCRIPTOR,
        type__pb2.DESCRIPTOR, state__pb2.DESCRIPTOR, ],
)


_REQUESTVERIFYTX = _descriptor.Descriptor(
    name='RequestVerifyTx',
    full_name='forge_abi.RequestVerifyTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.RequestVerifyTx.tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='states', full_name='forge_abi.RequestVerifyTx.states', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='assets', full_name='forge_abi.RequestVerifyTx.assets', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stakes', full_name='forge_abi.RequestVerifyTx.stakes', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='context', full_name='forge_abi.RequestVerifyTx.context', index=4,
            number=5, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_state', full_name='forge_abi.RequestVerifyTx.app_state', index=5,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=62,
    serialized_end=317,
)


_RESPONSEVERIFYTX = _descriptor.Descriptor(
    name='ResponseVerifyTx',
    full_name='forge_abi.ResponseVerifyTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseVerifyTx.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=319,
    serialized_end=374,
)


_REQUESTUPDATESTATE = _descriptor.Descriptor(
    name='RequestUpdateState',
    full_name='forge_abi.RequestUpdateState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.RequestUpdateState.tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='states', full_name='forge_abi.RequestUpdateState.states', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='assets', full_name='forge_abi.RequestUpdateState.assets', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stakes', full_name='forge_abi.RequestUpdateState.stakes', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='context', full_name='forge_abi.RequestUpdateState.context', index=4,
            number=5, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_state', full_name='forge_abi.RequestUpdateState.app_state', index=5,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=377,
    serialized_end=635,
)


_RESPONSEUPDATESTATE = _descriptor.Descriptor(
    name='ResponseUpdateState',
    full_name='forge_abi.ResponseUpdateState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseUpdateState.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='states', full_name='forge_abi.ResponseUpdateState.states', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='assets', full_name='forge_abi.ResponseUpdateState.assets', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stakes', full_name='forge_abi.ResponseUpdateState.stakes', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_state', full_name='forge_abi.ResponseUpdateState.app_state', index=4,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=638,
    serialized_end=857,
)


_REQUESTINFO = _descriptor.Descriptor(
    name='RequestInfo',
    full_name='forge_abi.RequestInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='forge_version', full_name='forge_abi.RequestInfo.forge_version', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=859,
    serialized_end=895,
)


_RESPONSEINFO = _descriptor.Descriptor(
    name='ResponseInfo',
    full_name='forge_abi.ResponseInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type_urls', full_name='forge_abi.ResponseInfo.type_urls', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.ResponseInfo.app_hash', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=897,
    serialized_end=948,
)


_REQUEST = _descriptor.Descriptor(
    name='Request',
    full_name='forge_abi.Request',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='verify_tx', full_name='forge_abi.Request.verify_tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='update_state', full_name='forge_abi.Request.update_state', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='info', full_name='forge_abi.Request.info', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='value', full_name='forge_abi.Request.value',
            index=0, containing_type=None, fields=[],
        ),
    ],
    serialized_start=951,
    serialized_end=1113,
)


_RESPONSE = _descriptor.Descriptor(
    name='Response',
    full_name='forge_abi.Response',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='verify_tx', full_name='forge_abi.Response.verify_tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='update_state', full_name='forge_abi.Response.update_state', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='info', full_name='forge_abi.Response.info', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='value', full_name='forge_abi.Response.value',
            index=0, containing_type=None, fields=[],
        ),
    ],
    serialized_start=1116,
    serialized_end=1282,
)

_REQUESTVERIFYTX.fields_by_name['tx'].message_type = type__pb2._TRANSACTION
_REQUESTVERIFYTX.fields_by_name['states'].message_type = state__pb2._ACCOUNTSTATE
_REQUESTVERIFYTX.fields_by_name['assets'].message_type = state__pb2._ASSETSTATE
_REQUESTVERIFYTX.fields_by_name['stakes'].message_type = state__pb2._STAKESTATE
_REQUESTVERIFYTX.fields_by_name['context'].message_type = type__pb2._ABCICONTEXT
_REQUESTVERIFYTX.fields_by_name['app_state'].message_type = state__pb2._FORGESTATE
_RESPONSEVERIFYTX.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_REQUESTUPDATESTATE.fields_by_name['tx'].message_type = type__pb2._TRANSACTION
_REQUESTUPDATESTATE.fields_by_name['states'].message_type = state__pb2._ACCOUNTSTATE
_REQUESTUPDATESTATE.fields_by_name['assets'].message_type = state__pb2._ASSETSTATE
_REQUESTUPDATESTATE.fields_by_name['stakes'].message_type = state__pb2._STAKESTATE
_REQUESTUPDATESTATE.fields_by_name['context'].message_type = type__pb2._ABCICONTEXT
_REQUESTUPDATESTATE.fields_by_name['app_state'].message_type = state__pb2._FORGESTATE
_RESPONSEUPDATESTATE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEUPDATESTATE.fields_by_name['states'].message_type = state__pb2._ACCOUNTSTATE
_RESPONSEUPDATESTATE.fields_by_name['assets'].message_type = state__pb2._ASSETSTATE
_RESPONSEUPDATESTATE.fields_by_name['stakes'].message_type = state__pb2._STAKESTATE
_RESPONSEUPDATESTATE.fields_by_name['app_state'].message_type = state__pb2._FORGESTATE
_REQUEST.fields_by_name['verify_tx'].message_type = _REQUESTVERIFYTX
_REQUEST.fields_by_name['update_state'].message_type = _REQUESTUPDATESTATE
_REQUEST.fields_by_name['info'].message_type = _REQUESTINFO
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['verify_tx'],
)
_REQUEST.fields_by_name['verify_tx'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['update_state'],
)
_REQUEST.fields_by_name['update_state'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['info'],
)
_REQUEST.fields_by_name['info'].containing_oneof = _REQUEST.oneofs_by_name['value']
_RESPONSE.fields_by_name['verify_tx'].message_type = _RESPONSEVERIFYTX
_RESPONSE.fields_by_name['update_state'].message_type = _RESPONSEUPDATESTATE
_RESPONSE.fields_by_name['info'].message_type = _RESPONSEINFO
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['verify_tx'],
)
_RESPONSE.fields_by_name['verify_tx'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['update_state'],
)
_RESPONSE.fields_by_name['update_state'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['info'],
)
_RESPONSE.fields_by_name['info'].containing_oneof = _RESPONSE.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['RequestVerifyTx'] = _REQUESTVERIFYTX
DESCRIPTOR.message_types_by_name['ResponseVerifyTx'] = _RESPONSEVERIFYTX
DESCRIPTOR.message_types_by_name['RequestUpdateState'] = _REQUESTUPDATESTATE
DESCRIPTOR.message_types_by_name['ResponseUpdateState'] = _RESPONSEUPDATESTATE
DESCRIPTOR.message_types_by_name['RequestInfo'] = _REQUESTINFO
DESCRIPTOR.message_types_by_name['ResponseInfo'] = _RESPONSEINFO
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestVerifyTx = _reflection.GeneratedProtocolMessageType(
    'RequestVerifyTx', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTVERIFYTX,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestVerifyTx)
    ),
)
_sym_db.RegisterMessage(RequestVerifyTx)

ResponseVerifyTx = _reflection.GeneratedProtocolMessageType(
    'ResponseVerifyTx', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEVERIFYTX,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseVerifyTx)
    ),
)
_sym_db.RegisterMessage(ResponseVerifyTx)

RequestUpdateState = _reflection.GeneratedProtocolMessageType(
    'RequestUpdateState', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTUPDATESTATE,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestUpdateState)
    ),
)
_sym_db.RegisterMessage(RequestUpdateState)

ResponseUpdateState = _reflection.GeneratedProtocolMessageType(
    'ResponseUpdateState', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEUPDATESTATE,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseUpdateState)
    ),
)
_sym_db.RegisterMessage(ResponseUpdateState)

RequestInfo = _reflection.GeneratedProtocolMessageType(
    'RequestInfo', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTINFO,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestInfo)
    ),
)
_sym_db.RegisterMessage(RequestInfo)

ResponseInfo = _reflection.GeneratedProtocolMessageType(
    'ResponseInfo', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEINFO,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseInfo)
    ),
)
_sym_db.RegisterMessage(ResponseInfo)

Request = _reflection.GeneratedProtocolMessageType(
    'Request', (_message.Message,), dict(
        DESCRIPTOR=_REQUEST,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.Request)
    ),
)
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType(
    'Response', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSE,
        __module__='abi_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.Response)
    ),
)
_sym_db.RegisterMessage(Response)


_FORGEAPPRPC = _descriptor.ServiceDescriptor(
    name='ForgeAppRpc',
    full_name='forge_abi.ForgeAppRpc',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=1284,
    serialized_end=1409,
    methods=[
        _descriptor.MethodDescriptor(
            name='process_one',
            full_name='forge_abi.ForgeAppRpc.process_one',
            index=0,
            containing_service=None,
            input_type=_REQUEST,
            output_type=_RESPONSE,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='process',
            full_name='forge_abi.ForgeAppRpc.process',
            index=1,
            containing_service=None,
            input_type=_REQUEST,
            output_type=_RESPONSE,
            serialized_options=None,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_FORGEAPPRPC)

DESCRIPTOR.services_by_name['ForgeAppRpc'] = _FORGEAPPRPC

# @@protoc_insertion_point(module_scope)



import logging
import os.path as path

from forge import ForgeConfig

logger = logging.getLogger('ec-config')

app_config = path.join(path.dirname(__file__), "forge.toml")

forge_config = ForgeConfig(app_config)

app_path = forge_config.get_app_path()

db_path = path.join(app_path, "ec.db")
logger.info('db_path: {}'.format(db_path))
